==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/binding/src/lib/reducer/LicenseReducer.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {
  LicenseSetAction, LicenseSetLicenseErrorAction,
  LicenseSetRegisterResultAction,
  LicenseSetUpdateErrorAction,
  LicenseSetUpdatingAction
} from "../actions/LicenseAction";
import type {
  LicenseState
} from "../state/RepetierState";
import {Action, createReducer, on} from "@ngrx/store";
import {INITIAL_LICENSE_STATE} from "../state/RepetierState";

const reducer = createReducer(INITIAL_LICENSE_STATE,
  on(LicenseSetAction, (state, payload) => {
    const features = payload.features;
    const newState = Object.assign({}, state, payload, {
      // tslint:disable-next-line
      supportPreviews: (features & 1) === 1,
      // tslint:disable-next-line
      supportWebcam: (features & 4) === 4,
      // tslint:disable-next-line
      supportSlicer: (features & 8) === 8,
      // tslint:disable-next-line
      supportExtendedStatistics: (features & 16) === 16,
      // tslint:disable-next-line
      supportLocalCloud: (features & 32) === 32,
      // tslint:disable-next-line
      supportModules: (features & 64) === 64,
      // tslint:disable-next-line
      isOEM: (features & 32768) === 32768,
      // tslint:disable-next-line
      isPro: (features & 2048) === 2048,
      // tslint:disable-next-line
      supportFirmwareUpload: (features & 256) === 256,
      dataLoaded: true
    });
    if (state.currentVersion !== "" && newState.currentVersion !== state.currentVersion) {
      location.reload();
    }
    return newState;
  }),
  on(LicenseSetUpdatingAction, (state, {updating}) =>
    Object.assign({}, state, {isUpdating: updating})),
  on(LicenseSetRegisterResultAction, (state, {result}) =>
    Object.assign({}, state, {registerResult: result})),
  on(LicenseSetUpdateErrorAction, (state, {error}) =>
    Object.assign({}, state, {updateError: error})),
  on(LicenseSetLicenseErrorAction, (state, {error}) =>
    Object.assign({}, state, {licenceError: error}))
);

export function LicenseReducer(state: LicenseState | undefined, action: Action): LicenseState {
  try {
    return reducer(state, action);
  } catch (e) {
    console.error("LicenseReducer error", e);
    return state;
  }
}

==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/binding/src/lib/reducer/LicenseReducer.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {
  LicenseSetAction, LicenseSetLicenseErrorAction,
  LicenseSetRegisterResultAction,
  LicenseSetUpdateErrorAction,
  LicenseSetUpdatingAction
} from "../actions/LicenseAction";
import type {
  LicenseState
} from "../state/RepetierState";
import {Action, createReducer, on} from "@ngrx/store";
import {INITIAL_LICENSE_STATE} from "../state/RepetierState";

const reducer = createReducer(INITIAL_LICENSE_STATE,
  on(LicenseSetAction, (state, payload) => {
    const features = payload.features;
    const newState = Object.assign({}, state, payload, {
      // eslint-disable-next-line
      supportPreviews: (features & 1) === 1,
      // eslint-disable-next-line
      supportWebcam: (features & 4) === 4,
      // eslint-disable-next-line
      supportSlicer: (features & 8) === 8,
      // eslint-disable-next-line
      supportExtendedStatistics: (features & 16) === 16,
      // eslint-disable-next-line
      supportLocalCloud: (features & 32) === 32,
      // eslint-disable-next-line
      supportModules: (features & 64) === 64,
      // eslint-disable-next-line
      isOEM: (features & 32768) === 32768,
      // eslint-disable-next-line
      isPro: (features & 2048) === 2048,
      // eslint-disable-next-line
      supportFirmwareUpload: (features & 256) === 256,
      dataLoaded: true
    });
    if (state.currentVersion !== "" && newState.currentVersion !== state.currentVersion) {
      location.reload();
    }
    return newState;
  }),
  on(LicenseSetUpdatingAction, (state, {updating}) =>
    Object.assign({}, state, {isUpdating: updating})),
  on(LicenseSetRegisterResultAction, (state, {result}) =>
    Object.assign({}, state, {registerResult: result})),
  on(LicenseSetUpdateErrorAction, (state, {error}) =>
    Object.assign({}, state, {updateError: error})),
  on(LicenseSetLicenseErrorAction, (state, {error}) =>
    Object.assign({}, state, {licenceError: error}))
);

export function LicenseReducer(state: LicenseState | undefined, action: Action): LicenseState {
  try {
    return reducer(state, action);
  } catch (e) {
    console.error("LicenseReducer error", e);
    return state;
  }
}
